sqlobject.constraints module — SQLObject 3.9.1 documentation

# sqlobject.constraints module

Constraints

exception `sqlobject.constraints.` `BadValue`(desc, obj, col, value, *args)

  Bases: `ValueError`

class `sqlobject.constraints.` `InList`(_l)

  Bases: `object`

class `sqlobject.constraints.` `MaxLength`(length)

  Bases: `object`

`sqlobject.constraints.` `isBool`(obj, col, value)

`sqlobject.constraints.` `isFloat`(obj, col, value)

`sqlobject.constraints.` `isInt`(obj, col, value)

`sqlobject.constraints.` `isString`(obj, col, value)

`sqlobject.constraints.` `notNull`(obj, col, value)